describe('people component tests', function() {
  it('should pass this canary test', function() {
    expect(true).to.be.true;
  });
  
  var sandbox;  
  var peopleComponent;
  var peopleService;
  var observable = { subscribe: function() {} };
  var updatePeopleBindStub = function() {};
  var updateErrorBindStub = function() {};

  beforeEach(function() {
    peopleService = {
      get: function() {},
    };   
  
    peopleComponent = new app.PeopleComponent(peopleService);
  
    sandbox = sinon.sandbox.create();    
  
    sandbox.stub(peopleComponent.updatePeople, 'bind')
           .withArgs(peopleComponent)
           .returns(updatePeopleBindStub);
  
    sandbox.stub(peopleComponent.updateError, 'bind')
           .withArgs(peopleComponent)
           .returns(updateErrorBindStub);
  
    sandbox.stub(peopleService, 'get')
           .withArgs()
           .returns(observable);
  });
  
  afterEach(function() {
    sandbox.restore();
  });
  
  it('should set the selector attribute', function() {
    var componentAnnotations = 
      Reflect.getMetadata('annotations', app.PeopleComponent)[0];
  
    expect(componentAnnotations.selector).to.be.eql('people-list');
  });
  
  it('should set the templateUrl attribute', function() {
    var componentAnnotations = 
      Reflect.getMetadata('annotations', app.PeopleComponent)[0];
  
    expect(componentAnnotations.templateUrl).to.be.eql(
      'people.component.html');
  });
  
  it('should initialize people to an empty array', function() {
    expect(peopleComponent.people).to.be.eql([]);
  });
  
  it('getPeople should register handlers with service', function() {
    var observableMock = 
      sandbox.mock(observable)
             .expects('subscribe')
             .withArgs(updatePeopleBindStub, updateErrorBindStub);
  
    peopleComponent.getPeople();
  
    observableMock.verify();
  });
  
  it('updatePeople should update people', function() {
    var peopleStub = [{sample: 1}];
    peopleComponent.updatePeople(peopleStub);
    expect(peopleComponent.people).to.be.eql(peopleStub);
  });
  
  it('updateError should update message', function() {
    peopleComponent.updateError('Not Found');
    expect(peopleComponent.message).to.be.eql('Not Found');
  });
  
  it('getPeople should be called on init', function() {
    var getPeopleMock = sandbox.mock(peopleComponent)
                              .expects('getPeople');
  
    peopleComponent.ngOnInit();
    getPeopleMock.verify();
  });
  
  it('should register necessary providers', function() {
    var componentAnnotations = 
      Reflect.getMetadata('annotations', app.PeopleComponent)[0];
  
    var expectedProviders = 
      [ng.http.HTTP_PROVIDERS, app.PeopleService];
  
    expect(componentAnnotations.providers).to.be.eql(expectedProviders);
  });
  
  it('PeopleService should be injected into the component', function() {
    var injectedServices = 
      Reflect.getMetadata('parameters', app.PeopleComponent);
  
    expect(injectedServices[0]).to.be.eql([app.PeopleService]);
  });
});
