describe('people service tests', function() {
  var sandbox;               
  var http;
  var observable;
  var peopleService;
  
  beforeEach(function() {                                
    sandbox = sinon.sandbox.create();
  
    http = {
      get: function() {},
    };
    
    peopleService = new app.PeopleService(http);
  
    observable = { 
      map: function() {},
      catch: function() {}
    };
  
  
    sandbox.stub(http, 'get')
           .withArgs('/people')
           .returns(observable);
  
    sandbox.stub(observable, 'map')
           .withArgs(peopleService.extractData)
           .returns(observable);
  
    sandbox.stub(observable, 'catch')
           .withArgs(peopleService.returnError)
           .returns(observable);
  });
  
  afterEach(function() {
    sandbox.restore();
  });
  
  it('get should make GET request to /people', function() {
    expect(peopleService.get()).to.be.eql(observable);
    expect(http.get.calledWith('/people')).to.be.true;
    expect(observable.map.calledWith(peopleService.extractData)).to.be.true;
    expect(observable.catch.calledWith(peopleService.returnError)).to.be.true;
  });
  
  it('extractData should return result from json()', function() {
    var fakeJSON = {};
    var response = {status: 200, json: function() { return fakeJSON; } };
    
    expect(peopleService.extractData(response)).to.be.eql(fakeJSON);
  });
  
  it('extractData should throw exception for invalid status', function() {
    var response = {status: 404 };
    
    expect(function() { 
      peopleService.extractData(response);
      }).to.throw('Request failed with status: 404');
  });
  
  it('returnError should return an error Observable', function() {
    var error = {message: 'oops'};
    var obervableThrowMock = 
      sandbox.mock(Rx.Observable)
             .expects('throw')
             .withArgs(error.message);
           
      peopleService.returnError(error);
      obervableThrowMock.verify();
  });      
  
  it('should inject HTTP into the constructor', function() {
    var injectedServices = 
      Reflect.getMetadata('parameters', app.PeopleService);
                                              
    expect(injectedServices[0]).to.be.eql([ng.http.Http]);
  });
});